<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AutoUpdater</name>
    <message>
        <source>No ssl configuration!
OpenSSL might not be installed.</source>
        <translation>Geen SSL-configuratie aangetroffen!
Mogelijk is OpenSSL niet geïnstalleerd.</translation>
    </message>
    <message>
        <source>Failed to save the Birdtray installer:
</source>
        <translation>Het opslaan van de Birdtray-installatiewizard is mislukt:
</translation>
    </message>
    <message>
        <source>Failed to download the Birdtray installer:
</source>
        <translation>Het downloaden van de Birdtray-installatiewizard is mislukt:
</translation>
    </message>
    <message>
        <source>Installer download failed</source>
        <translation>Downloaden mislukt</translation>
    </message>
    <message>
        <source>Update failed</source>
        <translation>Update mislukt</translation>
    </message>
    <message>
        <source>Failed to start the Birdtray installer.</source>
        <translation>Het starten van de Birdtray-installatiewizard is mislukt.</translation>
    </message>
</context>
<context>
    <name>BirdtrayApp</name>
    <message>
        <source>Display the contents of the given mork database.</source>
        <translation>Bekijk de inhoud van de opgegeven mork-databank.</translation>
    </message>
    <message>
        <source>databaseFile</source>
        <translation>databankbestand</translation>
    </message>
    <message>
        <source>Decode an IMAP Utf7 string.</source>
        <translation>Decodeer een IMAP-Utf7-string.</translation>
    </message>
    <message>
        <source>string</source>
        <translation>string</translation>
    </message>
    <message>
        <source>Show the settings.</source>
        <translation>Toon het instellingenvenster.</translation>
    </message>
    <message>
        <source>Reset the settings to the defaults.</source>
        <translation>Zet de instellingen terug op hun standaardwaarden.</translation>
    </message>
    <message>
        <source>Toggle the Thunderbird window.</source>
        <translation>Toon/Verberg het Thunderbird-venster.</translation>
    </message>
    <message>
        <source>Show the Thunderbird window.</source>
        <translation>Toon het Thunderbird-venster.</translation>
    </message>
    <message>
        <source>Hide the Thunderbird window.</source>
        <translation>Verberg het Thunderbird-venster.</translation>
    </message>
    <message>
        <source>Write log to a file.</source>
        <translation>Sla een logboek op.</translation>
    </message>
    <message>
        <source>A free system tray notification for new mail for Thunderbird.</source>
        <translation>Een gratis systeemvakprogramma dat meldingen toont van Thunderbird.</translation>
    </message>
    <message>
        <source>file</source>
        <translation>bestand</translation>
    </message>
    <message>
        <source>Sorry, the system tray cannot be controlled by this add-on on your operating system.</source>
        <translation>Het systeemvak van uw besturingssysteem kan niet worden beheerd middels deze add-on.</translation>
    </message>
</context>
<context>
    <name>DialogAddEditNewEmail</name>
    <message>
        <source>&quot;New Email&quot; Entry</source>
        <translation>Item &apos;Nieuwe e-mail&apos;</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>(Optional) Prefilled fields</source>
        <translation>Vooringevulde velden (optioneel)</translation>
    </message>
    <message>
        <source>Email subject:</source>
        <translation>Onderwerp:</translation>
    </message>
    <message>
        <source>Email message text:</source>
        <translation>Berichtinhoud:</translation>
    </message>
    <message>
        <source>Email recipient:</source>
        <translation>Ontvanger:</translation>
    </message>
    <message>
        <source>No name specified</source>
        <translation>Geen naam opgegeven</translation>
    </message>
    <message>
        <source>The name cannot be empty.</source>
        <translation>Voer een naam in.</translation>
    </message>
</context>
<context>
    <name>DialogLogOutput</name>
    <message>
        <source>Debug log viewer</source>
        <translation>Foutopsporingslogboek</translation>
    </message>
</context>
<context>
    <name>DialogSettings</name>
    <message>
        <source>Birdtray Settings</source>
        <translation>Birdtray-instellingen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>New Mail Notification</source>
        <translation>Melding bij nieuwe e-mail</translation>
    </message>
    <message>
        <source>Show unread count</source>
        <translation>Aantal ongelezen e-mails tonen</translation>
    </message>
    <message>
        <source>Different icon when unread:</source>
        <translation>Aangepast pictogram bij ongelezen e-mails:</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <source>Fastest</source>
        <translation>Snelst</translation>
    </message>
    <message>
        <source>Icon (Ctrl-click to reset):</source>
        <translation>Pictogram (Ctrl-klik herstelt de instelling):</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This notification color will be used when more than one monitored account has unread emails.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Deze meldingskleur wordt gebruikt als er ongelezen e-mails zijn op meer dan één bijgehouden account.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Multiple notification color:</source>
        <translation>Meldingskleur meerdere accounts:</translation>
    </message>
    <message>
        <source>Blinking speed:</source>
        <translation>Knippersnelheid:</translation>
    </message>
    <message>
        <source>Font style:</source>
        <translation>Lettertypestijl:</translation>
    </message>
    <message>
        <source>Bold:</source>
        <translation>Vetgedrukt:</translation>
    </message>
    <message>
        <source>Notification border color:</source>
        <translation>Randkleur van meldingen:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Breedte:</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>Monitoring</source>
        <translation>Bijhouden</translation>
    </message>
    <message>
        <source>Accounts to monitor</source>
        <translation>Bij te houden accounts</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Aanpassen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Allow ignoring the current unread email counter</source>
        <translation>Toestaan dat het aantal ongelezen e-mails genegeerd mag worden</translation>
    </message>
    <message>
        <source>Hiding</source>
        <translation>Verbergen</translation>
    </message>
    <message>
        <source>Launching and Hiding</source>
        <translation>Opstarten en verbergen</translation>
    </message>
    <message>
        <source>Start Thunderbird when Birdtray starts</source>
        <translation>Thunderbird starten als Birdtray start</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;When both Thunderbird and Birdtray are set to start with the operating system, this usually results in two copies of Thunderbird being launched. Here you can add a delay before Thunderbird is launched, to prevent this.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Als zowel Thunderbird en Birdtray automatisch opstarten, dan wordt Thunderbird normaliter twee keer gestart. Hier kunt een vertraging opgeven om dit te voorkomen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source> second delay</source>
        <translation> seconde(n) vertraging</translation>
    </message>
    <message>
        <source>with a </source>
        <translation>met een </translation>
    </message>
    <message>
        <source>and hide it</source>
        <translation>en verberg het</translation>
    </message>
    <message>
        <source>Terminate Thunderbird when quitting Birdtray</source>
        <translation>Thunderbird afsluiten als Birdtray wordt afgesloten</translation>
    </message>
    <message>
        <source>Hide/show Thunderbird window when clicking on tray icon</source>
        <translation>Thunderbird tonen/verbergen door op het systeemvakpictogram te klikken</translation>
    </message>
    <message>
        <source>Hide Thunderbird window when it is minimized</source>
        <translation>Thunderbird verbergen als het venster geminimaliseerd wordt</translation>
    </message>
    <message>
        <source>Show red X in tray icon if Thunderbird is not running</source>
        <translation>Rode &apos;X&apos; tonen op systeemvakpictogram als Thunderbird niet is gestart</translation>
    </message>
    <message>
        <source>Restart Thunderbird if it was closed</source>
        <translation>Thunderbird herstarten na afsluiten</translation>
    </message>
    <message>
        <source>New Email</source>
        <translation>Nieuwe e-mail</translation>
    </message>
    <message>
        <source>Enable New Email submenu</source>
        <translation>Menu &apos;Nieuwe e-mail&apos; inschakelen</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <source>Please do not change these settings unless you understand what you&apos;re doing.</source>
        <translatorcomment>checkTranslation ignore: punctuation_end_differ</translatorcomment>
        <translation>Pas deze instellingen alleen aan als u weet wat u doet!</translation>
    </message>
    <message>
        <source>Thunderbird window name pattern:</source>
        <translation>Naampatroon van Thunderbird-venster:</translation>
    </message>
    <message>
        <source>Minimum notification font size:</source>
        <translation>Minimale lettergrootte op meldingen:</translation>
    </message>
    <message>
        <source> points</source>
        <translation> punten</translation>
    </message>
    <message>
        <source>When blinking, use the fade-in/fade-out transition (increases CPU use!)</source>
        <translation>Overgangsanimatie gebruiken tijdens knipperen (dit verhoogt het CPU-verbruik!)</translation>
    </message>
    <message>
        <source>Make the system tray icon</source>
        <translation>Systeemvakpictogram doorzichtig maken</translation>
    </message>
    <message>
        <source>Check for new updates on startup</source>
        <translation>Controleren op updates tijdens opstarten</translation>
    </message>
    <message>
        <source>Check now</source>
        <translation>Nu controleren</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Version check failed</source>
        <translation>Versiecontrole mislukt</translation>
    </message>
    <message>
        <source>Failed to check for a new Birdtray version:
</source>
        <translation>Het controleren op updates is mislukt:
</translation>
    </message>
    <message>
        <source>Checking...</source>
        <translation>Bezig met controleren...</translation>
    </message>
    <message>
        <source>Choose the new icon</source>
        <translation>Kies het nieuwe pictogram</translation>
    </message>
    <message>
        <source>Images (*.png *.svg *.svgz)</source>
        <translation>Afbeeldingen (*.png *.svg *.svgz)</translation>
    </message>
    <message>
        <source>Invalid icon</source>
        <translation>Ongeldig pictogram</translation>
    </message>
    <message>
        <source>Could not load the icon from this file.</source>
        <translation>Het pictogram kan niet worden geladen uit dit bestand.</translation>
    </message>
    <message>
        <source>Thunderbird command line:</source>
        <translation>Thunderbird-opdrachtregel:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This is the full command-line (with arguments) which will be used to start Thunderbird. Arguments are space-separated, but spaces in quotes are allowed, i.e. something like &lt;span style=&quot; font-weight:600;&quot;&gt;&amp;quot;C:\Program Files\tb.exe&amp;quot; --profile test&lt;/span&gt; will work.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;De volledige opdrachtregel (met argumenten) welke worden gebruikt om Thunderbird op te starten. Argumenten dienen spatiegescheiden te zijn, maar spaties tussen dubbele aanhalingstekens zijn toegestaan. Voorbeeld: &lt;span style=&quot; font-weight:600;&quot;&gt;&amp;quot;C:\Program Files\tb.exe&amp;quot; --profile test&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Ignore all unread email that are present when Birdtray starts. Only new emails will be taken into account by the unread counter.</source>
        <translation>Negeer alle ongelezen e-mails die beschikbaar zijn als Birdtray opstart. Alleen nieuwe e-mails worden geteld door de ongelezen e-mail-aanduiding.</translation>
    </message>
    <message>
        <source>Choose one or more MSF files</source>
        <translation>Selecteer één of meerdere MSF-bestanden</translation>
    </message>
    <message>
        <source>Mail Index (*.msf)</source>
        <translation>Mail-index (*.msf)</translation>
    </message>
    <message>
        <source>No new updates found</source>
        <translation>Geen updates beschikbaar</translation>
    </message>
    <message>
        <source>opaque when new mail is present,</source>
        <translatorcomment>checkTranslation ignore: punctuation_end_differ</translatorcomment>
        <translation>ondoorzichtig als er nieuwe e-mails zijn;</translation>
    </message>
    <message>
        <source>hide it if no new mail is present.</source>
        <translation>verbergen als er geen nieuwe e-mails zijn.</translation>
    </message>
    <message>
        <source>Show log window</source>
        <translation>Logboek tonen</translation>
    </message>
    <message>
        <source>Force index file re-read every</source>
        <translation>Indexbestand opnieuw uitlezen, elke</translation>
    </message>
    <message>
        <source> seconds</source>
        <translation> seconden</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If this box is checked, the Birdtray icon will show the number of unread emails.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;If it is unchecked, no count will be shown, and you will only know about unread emails because of the blinking or different icon, depending on your settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Kruis dit aan om het aantal ongelezen e-mails te tonen op het Birdtray-pictogram.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;Als u dit niet aankruist, dan kunt u alleen zien dat er ongelezen e-mails zijn aan het knipperende of anders uitziende pictogram (afhankelijk van uw instellingen).&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Translations are powered by the community:</source>
        <translation>Birdtray wordt vertaald door de gemeenschap:</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Vertalers</translation>
    </message>
    <message>
        <source>Active maintainers</source>
        <translation>Actieve beheerders</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation>Bijdragers</translation>
    </message>
    <message>
        <source>Unread change cmd:</source>
        <translation>Ongelezen wijziging-opdracht:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select mail folders for watching.&lt;br/&gt;&lt;br/&gt;If the dialog doesn&apos;t show your folder, &lt;i&gt;Ctrl + Shift click&lt;/i&gt; to open a file selection dialog that allows adding any mork file.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Selecteer de e-mailmappen die u wilt bijhouden.&lt;br/&gt;&lt;br/&gt;Als het venster een map niet toont, &lt;i&gt;gebruik dan Ctrl + Shift + klik&lt;/i&gt; om een bestandsselectievenster te openen zodat u een mork-bestand kunt toevoegen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Could not load the icon from this file. Try loading the icon in an image editing tool and saving it in a different format.</source>
        <translation>Het pictogram kan niet worden geladen uit het bestand. Open het in een afbeeldingsbewerker en sla het op als een ander bestandsformaat.</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This changes the font thickness, i.e. makes the font bold.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Dit past de dikte van het lettertype aan - maak het bijv. vetgedrukt.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If not empty, this command will be invoked every time the unread counter changes (including when it becomes zero). It is invoked via shell, as-is, with %NEW% replaced by the new unread count value and %OLD% replaced with the old unread count value (which may be the same as new).&lt;/p&gt;&lt;p&gt;Most users don&apos;t need this functionality and should leave it empty.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Als dit niet leeggelaten wordt, dan wordt de opdracht aangeroepen telkens als de ongelezenteller verandert (inclusief als deze de nul bereikt). Deze wordt aangeroepen via de shell waar %NEW% vervangen wordt door de huidige ongelezen waarde en %OLD% door de vorige (welke dezelfde kan zijn als de huidige).&lt;/p&gt;&lt;p&gt;De meeste gebruikers hebben deze functionaliteit niet nodig dienen het vak leeg te laten.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Check for new updates when Birdtray starts.</source>
        <translation>Controleren op updates tijdens opstarten.</translation>
    </message>
    <message>
        <source>Check for a new Birdtray version.</source>
        <translation>Controleer of er een nieuwe Birdtray-versie beschikbaar is.</translation>
    </message>
    <message>
        <source>Support non-NETWM compliant WMs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your desktop manager is not fully NETWM compliant, you may need to check this checkbox so it can detect Thunderbird window and is able to minimise and hide it.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When hiding Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When showing Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If enabled, this option adds the &amp;quot;Ignore currently unread emails&amp;quot; action to the context menu. This action allows you to ignore the emails which are currently unread. Birdtray would then pretend there are no unread emails left, and would only show new emails over the ignored count.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;For example, if there were 10 unread emails, and you clicked on &amp;quot;Ignore&amp;quot; action, Birdtray will show no unread email indicator as long as unread email count remains at 10. Once new email is received and you have 11 total unread emails, Birdtray will show the new email count as 1.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Kruis dit aan om de optie &amp;quot;Huidige ongelezen e-mails negeren &amp;quot; toe te voegen aan het rechtermuisknopmenu. Birdtray doet dan alsof er geen ongelezen e-mails meer zijn totdat er nieuwe e-mails binnenkomen.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;Voorbeeld: Als er 11 ongelezen e-mails zijn en u heeft de optie &amp;quot;Negeren&amp;quot; geactiveerd, dan toont Birdtray geen indicator zolang het aantal op 10 blijft. Zodra er weer nieuwe e-mails binnenkomen, toont Birdtray het aantal vanaf dan, beginnende bij 1.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Start Thunderbird by clicking on the tray icon if it was closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When detecting a change, wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> milliseconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>before updating the unread counter.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thunderbird process name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Birdtray version [VERSION] compiled at [DATE] using Qt [QT_VERSION].&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Copyright (C) 2018 by George Yunaev, &lt;/span&gt;&lt;a href=&quot;mailto:gyunaev@ulduzsoft.com&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;gyunaev@ulduzsoft.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Birdtray is FREE SOFTWARE, which is licensed under General Public License v3. To clarify further, you can use it for any purpose, including commercial, without paying anything. &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;To ask for help, request a feature or report a bug use the &lt;/span&gt;&lt;a href=&quot;https://github.com/gyunaev/birdtray&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;Github project page&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;For those of you who appreciate my work on Birdtray, which is being developed in my free time, you can do it here: &lt;/span&gt;&lt;a href=&quot;https://paypal.me/ulduzsoft&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;https://paypal.me/ulduzsoft&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Thank you for your continuous support!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Birdtray-versie [VERSION], gecompileerd op [DATE] (Qt [QT_VERSION]).&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Copyright (C) 2018 by George Yunaev, &lt;/span&gt;&lt;a href=&quot;mailto:gyunaev@ulduzsoft.com&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;gyunaev@ulduzsoft.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Birdtray is VRIJE SOFTWARE, uitgebracht onder de General Public License v3. U mag dit gebruiken voor alle doeleinden, inclusief commerciële, zonder daarvoor te betalen. &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Als u hulp wilt, een idee wilt delen of een bug wilt melden, dan kan dit op de &lt;/span&gt;&lt;a href=&quot;https://github.com/gyunaev/birdtray&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;Github-projectpagina&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Waardeert u al het harde werk aan Birdtray dat ik verricht in mijn vrije tijd? Dan kunt u een donatie doen: &lt;/span&gt;&lt;a href=&quot;https://paypal.me/ulduzsoft&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;https://paypal.me/ulduzsoft&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Bedankt voor uw ondersteuning!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>Log</name>
    <message>
        <source>Fatal</source>
        <translation>Onmogelijk</translation>
    </message>
    <message>
        <source>Fatal error: %1

Log file is written into file %2</source>
        <translation>Fatale fout: %1

Het logboek is opgeslagen als %2</translation>
    </message>
    <message>
        <source>Failed to open log file %1: %2</source>
        <translation>Het logboek &apos;%1&apos; kan niet worden geopend: %2</translation>
    </message>
</context>
<context>
    <name>MailAccountDialog</name>
    <message>
        <source>Thunderbird Profiles Directory</source>
        <translation>Thunderbird-profielenmap</translation>
    </message>
    <message>
        <source>Select the directory that contains the Thunderbird profiles.</source>
        <translation>Kies de map die de Thunderbird-profielen bevat.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bladeren</translation>
    </message>
    <message>
        <source>Select Accounts</source>
        <translation>Accounts selecteren</translation>
    </message>
    <message>
        <source>Select the mail accounts you want to monitor.</source>
        <translation>Selecteer de e-mailaccounts die u wilt bijhouden.</translation>
    </message>
    <message>
        <source>Notification Color</source>
        <translation>Meldingskleur</translation>
    </message>
    <message>
        <source>If you monitor multiple folders, the default notification color is used to show the sum of all unread mails.</source>
        <translation>Als u meerdere mappen bijhoudt, dan wordt de standaardkleur gebruikt om het totaalaantal ongelezen e-mails aan te duiden.</translation>
    </message>
    <message>
        <source>Choose the Thunderbird profiles path</source>
        <translation>Kies het Thunderbird-profielenpad</translation>
    </message>
    <message>
        <source>No folder selected</source>
        <translation>Geen map gekozen</translation>
    </message>
    <message>
        <source>No mail folder was selected to monitor.
Do you want to continue?</source>
        <translation>U heeft geen bij te houden map gekozen.
Wilt u doorgaan?</translation>
    </message>
    <message>
        <source>Email Folder</source>
        <translation>E-mailmap</translation>
    </message>
    <message>
        <source>No mail profiles were found.
Please make sure you selected the correct profiles directory.</source>
        <translation>Geen e-mailprofielen aangetroffen.
Zorg ervoor dat u de juiste profielenmap heeft gekozen.</translation>
    </message>
    <message>
        <source>%1 (Profile)</source>
        <translation>%1 (profiel)</translation>
    </message>
</context>
<context>
    <name>ModelAccountTree</name>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message>
        <source>Notification color</source>
        <translation>Meldingskleur</translation>
    </message>
</context>
<context>
    <name>ModelNewEmails</name>
    <message>
        <source>Menu entry item</source>
        <translation>Menuverwijzing</translation>
    </message>
</context>
<context>
    <name>MorkParser</name>
    <message>
        <source>Couldn&apos;t open file: </source>
        <translation>Bestand kan niet worden geopend: </translation>
    </message>
    <message>
        <source>Unsupported version.</source>
        <translation>Niet-ondersteunde versie.</translation>
    </message>
    <message>
        <source>Invalid format.</source>
        <translation>Ongeldig formaat.</translation>
    </message>
    <message>
        <source>Parsing error.</source>
        <translation>Verwerkingsfout.</translation>
    </message>
    <message>
        <source>Unexpected EOF.</source>
        <translation>Onverwacht bestandseinde.</translation>
    </message>
    <message>
        <source>Invalid comment.</source>
        <translation>Ongeldige opmerking.</translation>
    </message>
    <message>
        <source>Format error.</source>
        <translation>Formaatfout.</translation>
    </message>
    <message>
        <source>Unexpected end of group.</source>
        <translation>Onverwacht groepseinde.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Could not save the settings</source>
        <translation>Kan instellingen niet opslaan</translation>
    </message>
    <message>
        <source>Could not save the settings into file %1:
%2</source>
        <translation>De instellingen kunnen niet worden opgeslagen in %1:
%2</translation>
    </message>
    <message>
        <source>Sqlite based accounts migrated</source>
        <translation>Op Sqlite gebaseerde accounts zijn gemigreerd</translation>
    </message>
    <message>
        <source>You had configured monitoring of one or more mail folders using the Sqlite parser. This method has been removed. Your configurations has been migrated to the Mork parser, but some configured mail folders could not be found.</source>
        <translation>U had ingesteld dat één of meerdere e-mailmappen bijgehouden moesten worden middels de Sqlite-verwerker, maar deze methode is verwijderd. Uw instellingen zijn gemigreerd naar de Mork-verwerker, maar enkele ingestelde e-mailmappen zijn niet aangetroffen.</translation>
    </message>
    <message>
        <source>You had configured monitoring of one or more mail accounts using the Sqlite parser. This method has been removed. Your configurations has been migrated to the Mork parser. Please verify that all accounts were mapped correctly.</source>
        <translation>U had ingesteld dat één of meerdere e-mailmappen bijgehouden moesten worden middels de Sqlite-verwerker, maar deze methode is verwijderd. Uw instellingen zijn gemigreerd naar de Mork-verwerker. Controleer of alle accounts juist zijn gemigreerd.</translation>
    </message>
    <message>
        <source>Cannot load default system tray icon.</source>
        <translation>Het laden van het standaard systeemvakpictogram is mislukt.</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Would you like to set up Birdtray?</source>
        <translation>Wilt u Birdtray instellen?</translation>
    </message>
    <message>
        <source>You have not yet configured any email folders to monitor. Would you like to do it now?</source>
        <translation>U heeft nog geen bij te houden mappen opgegeven. Wilt u dat nu doen?</translation>
    </message>
    <message>
        <source>Show Thunderbird</source>
        <translation>Thunderbird tonen</translation>
    </message>
    <message>
        <source>Hide Thunderbird</source>
        <translation>Thunderbird verbergen</translation>
    </message>
    <message>
        <source>New Email</source>
        <translation>Nieuwe e-mail</translation>
    </message>
    <message>
        <source>Blank</source>
        <translation>Blanco</translation>
    </message>
    <message>
        <source>New Email Message</source>
        <translation>Nieuw e-mailbericht</translation>
    </message>
    <message>
        <source>5 minutes</source>
        <translation>5 minuten</translation>
    </message>
    <message>
        <source>10 minutes</source>
        <translation>10 minuten</translation>
    </message>
    <message>
        <source>30 minutes</source>
        <translation>30 minuten</translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation>1 uur</translation>
    </message>
    <message>
        <source>4 hours</source>
        <translation>4 uur</translation>
    </message>
    <message>
        <source>Snooze for ...</source>
        <translatorcomment>checkTranslation ignore: punctuation_end_differ</translatorcomment>
        <translation>Onderdrukken:</translation>
    </message>
    <message>
        <source>Unsnooze</source>
        <translation>Niet meer onderdrukken</translation>
    </message>
    <message>
        <source>Ignore unread emails</source>
        <translation>Ongelezen e-mails negeren</translation>
    </message>
    <message>
        <source>Settings...</source>
        <translation>Instellingen...</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Cannot start Thunderbird</source>
        <translation>Thunderbird kan niet worden opgestart</translation>
    </message>
    <message>
        <source>Error starting Thunderbird, because we could not attach to the updater:

%1</source>
        <translation>Het opstarten van Thunderbird is mislukt omdat de updater niet kan worden gekoppeld:

%1</translation>
    </message>
    <message>
        <source>Ignore unread emails (now %1)</source>
        <translation>Ongelezen e-mails negeren (momenteel %1)</translation>
    </message>
    <message>
        <source>Error starting Thunderbird as &apos;%1 %2&apos;:

%3</source>
        <translation>Thunderbird kan niet worden gestart als &apos;%1 %2&apos;:

%3</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation>Waarschuwing: %1</translation>
    </message>
    <message>
        <source>Don&apos;t ask again</source>
        <translation>Niet meer vragen</translation>
    </message>
</context>
<context>
    <name>UnreadMonitor</name>
    <message>
        <source>Unable to watch %1 for changes.</source>
        <translation>&apos;%1&apos; kan niet worden bijgehouden.</translation>
    </message>
    <message>
        <source>Unable to read from %1.</source>
        <translation>&apos;%1&apos; kan niet worden uitgelezen.</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Birdtray Update</source>
        <translation>Birdtray-update</translation>
    </message>
    <message>
        <source>Current version:</source>
        <translation>Huidige versie:</translation>
    </message>
    <message>
        <source>A new version of Birdtray is available.</source>
        <translation>Er is een nieuwe versie van Birdtray beschikbaar.</translation>
    </message>
    <message>
        <source>New version:</source>
        <translation>Nieuwe versie:</translation>
    </message>
    <message>
        <source>Download size:</source>
        <translation>Downloadgrootte:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Ignore this version</source>
        <translation>Deze versie negeren</translation>
    </message>
    <message>
        <source>ca. %1 Mb</source>
        <translation>ca. %1 mb</translation>
    </message>
    <message>
        <source>Update and restart</source>
        <translation>Bijwerken en opnieuw starten</translation>
    </message>
</context>
<context>
    <name>UpdateDownloadDialog</name>
    <message>
        <source>Birdtray Update</source>
        <translation>Birdtray-update</translation>
    </message>
    <message>
        <source>Downloading Birdtray update...</source>
        <translation>Bezig met downloaden van Birdtray-update...</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>Achtergrond</translation>
    </message>
    <message>
        <source>Downloading Birdtray installer...</source>
        <translation>Bezig met downloaden van Birdtray-installatiewizard...</translation>
    </message>
    <message>
        <source>Download finished. Restart and update Birdtray?</source>
        <translation>Het downloaden is afgerond. Wilt u Birdtray opnieuw starten om bij te werken?</translation>
    </message>
    <message>
        <source>Downloading Birdtray installer... (%1 Mb / %2 Mb).</source>
        <translation>Bezig met downloaden van Birdtray-installatiewizard... (%1 mb/%2 mb).</translation>
    </message>
</context>
</TS>
